---
title: 결제연동
category: 관리자콘솔 (관리자콘솔 사용 가이드) > 결제연동 > 결제 연동
seo:
  title: 결제연동
  description: 상점정보, 테스트/실 연동관리, 결제알림, 추가 설정 관리 등 관리자콘솔 내 결제연동을 위한 정보들을 확인해보세요.
  keywords:
    - 결제연동
    - 관리자콘솔
    - 포트원
tags:
  - 공통
  - 관리자콘솔
pgCompanies:
  - 공통
searchTags:
  - 화이트리스트
  - 웹훅설정
  - 실연동
  - 테스트연동
  - apikeys
  - 식별코드
  - 하위상점
  - 대표상점
---

### **결제연동**

#### **1. 상점정보**



- 대표상점
  - 최초 회원가입된 계정은 \[대표상점]으로 분류되며 하위상점을 추가하신 경우 변경 버튼을 통해 하위상점의 메뉴로 이동할 수 있습니다.



- 내 식별코드 ・ API Keys
  - 고객사 식별코드 : 결제연동시(결제창 호출시) 사용하는 식별코드
  - REST API Key : 결제연동시(REST API 호출시) 사용하는 Key
  - REST API Secret : 결제연동시(REST API 호출시) 사용하는 Key

#### **2. 테스트/실 연동관리**

**테스트 및 실 연동환경을 위해 상점정보를 설정하는 메뉴입니다.**





- **결제대행사 설정 및 추가**

<Indent level="1">

- 테스트/ 실 연동 선택
- PG사 선택
- PG사의 서비스 수단 선택 (결제 모듈)

</Indent>

#### **3. 결제알림(Webhook) 관리**

**안정적인 결제연동을 위해 웹훅 서비스를 사용하시기 위한 메뉴입니다.**



- Endpoint URL : 웹훅을 수신받을 귀사(고객사)의 URL 을 입력합니다.
- 호출테스트 : 지정하신 URL로 정상호출이 되는지 테스트 가능합니다.

<Callout title="V2 웹훅 연동 가이드 보러가기 ↗" icon="" />

<Callout title="V1 웹훅 연동 가이드 보러가기 ↗" icon="" />

#### **4. 추가 설정 관리**



- 연동가능한 IP를 관리하실 수 있는 화이트리스트 설정이 가능합니다.
- 포트원의 API 호출시 특정 IP 에서만 API를 호출 할 수 있도록 제한할 수 있습니다.
